@@ -1,10 +1,9 @@
 package Math::Cryptarithm;
 
+use 5.034000;
 use strict;
 use warnings;
 use Algorithm::Permute;
-use v5.10.0;
-use version;
 
 require Exporter;
 
@@ -20,7 +19,7 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = qv('v0.20.2');
+our $VERSION = '0.01';
 
 
 # Preloaded methods go here.
@@ -83,7 +82,7 @@ sub equations {
     $_[0]->{_equations};
 }
 
-sub solve_alphabetvalue_hash {
+sub solve {
     my ($self) = @_;
     my @eqs = @{$self->equations};
     my @answers = ();
@@ -110,13 +109,11 @@ sub solve_alphabetvalue_hash {
                 _replacement( $eqs_lhs[$i] , \@arr_alphabets, \@res );
             my $str_rhs = 
                 _replacement( $eqs_rhs[$i] , \@arr_alphabets, \@res );
-            my $val_lhs = eval $str_lhs;
-            my $val_rhs = eval $str_rhs;
             die "LHS is not numeric:\n $eqs_lhs[$i]\n\"$str_lhs\"\n" 
-                if $val_lhs  !~ m/^[0-9]+$/;
+                if (eval $str_lhs) !~ m/^[0-9]+$/;
             die "RHS is not numeric:\n $eqs_rhs[$i]\n\"$str_rhs\"\n" 
-                if $val_rhs !~ m/^[0-9]+$/;
-            next COMBIN_TEST unless $val_lhs == $val_rhs;
+                if (eval $str_rhs) !~ m/^[0-9]+$/;
+            next COMBIN_TEST unless (eval $str_lhs) == (eval $str_rhs) ;
             $ok = 1;
         }
         if ($ok) {
@@ -133,7 +130,7 @@ sub solve_alphabetvalue_hash {
 sub solve_ans_in_equations {
     my ($self) = @_;
     my @eqs = @{$self->equations};
-    my @answers_of_hashes = $self->solve_alphabetvalue_hash()->@*;
+    my @answers_of_hashes = $self->solve()->@*;
     my @answers_in_eq;
     for my $my_hash (@answers_of_hashes) {
         my @a_set_of_answer_in_eq;
@@ -160,7 +157,7 @@ Math::Cryptarithm - Solving simple cryptarithm.
 
 =head1 VERSION
 
-Version 0.20.2
+Version 0.01
 
 
 =head1 DESCRIPTION
@@ -203,7 +200,7 @@ See L<English Wikipedia: Verbal arithmetic|https://en.wikipedia.org/wiki/Verbal_
         "ABA * B = ABA"
     ];
 
-    my $abcd_ans = Math::Cryptarithm->new($abcd)->solve_alphabetvalue_hash();
+    my $abcd_ans = Math::Cryptarithm->new($abcd)->solve();
 
     say scalar $abcd_ans->@*;             # 1
     say $abcd_ans->[0]->{"A"};            # 2
@@ -213,7 +210,7 @@ See L<English Wikipedia: Verbal arithmetic|https://en.wikipedia.org/wiki/Verbal_
 
 
     my $magical_seven = ["ABCDEF * 6 = DEFABC"];
-    my $magical_seven_ans = Math::Cryptarithm->new($magical_seven)->solve_alphabetvalue_hash();
+    my $magical_seven_ans = Math::Cryptarithm->new($magical_seven)->solve();
 
     print Dumper($magical_seven_ans);
 
@@ -222,7 +219,7 @@ See L<English Wikipedia: Verbal arithmetic|https://en.wikipedia.org/wiki/Verbal_
 
 =head1 METHODS
 
-=head2 solve_alphabetvalue_hash()
+=head2 solve()
 
 Return a list object of hashes with all possible solutions. Different letters represent different digits.
 
@@ -236,13 +233,13 @@ Return the possible solutions in "decrypted equations" form. See the section Syn
 
 Currently the module runs slowly when the number of variables is equal to or more than 6. Using a backtracking as the algorithm should improve the performance of the module.
 
-=head2 "?"
+=head2 setRep($symbol)
 
-Allow "?" to represent arbitary digits. See the related Wikipedia entry (L<zh|https://zh.wikipedia.org/wiki/%E8%9F%B2%E9%A3%9F%E7%AE%97> or L<ja|https://ja.wikipedia.org/wiki/%E8%99%AB%E9%A3%9F%E3%81%84%E7%AE%97>) using "square box" representing any possible digits.
+Whether allow repetitions. 1 is no repetitions. 0 means repetitions are allowed. Default should be 1.
 
 =head2 setLeadingZeros($symbol)
 
-To determine whether allow zeros as possible values as the leading part of a number. 1 is allowed. 0 means not allowed. Default should be 1.
+Whether allow zeros as possible values as the leading part of a word. 1 is allowed. 0 means not allowed. Default should be 1.
 
 =head1 AUTHOR
 
